@@ -732,7 +732,7 @@ class bus:
     array([0., 3.])
     >>> heat_bus.comps.loc[fgc]['char'].y
     array([-1., -1.])
-    >>> round(chp.ti.val)
+    >>> round(chp.ti.val, 0)
     25813247.0
     >>> round(chp.Q1.val + chp.Q2.val, 0)
     8896898.0
@@ -745,7 +745,7 @@ class bus:
     >>> power_bus.set_attr(P=7.5e6)
     >>> mode = 'offdesign'
     >>> nw.solve(mode=mode, design_path='tmp', init_path='tmp')
-    >>> round(chp.ti.val)
+    >>> round(chp.ti.val, 0)
     21187528.0
     >>> round(chp.P.val / chp.P.design, 3)
     0.761
@@ -902,7 +902,7 @@ class bus:
                         comp = c['c']
                         msg = (
                             'The dictionary keyword "c" will be removed in '
-                            'TESPy version 0.3.2. Please use "comp" instead.')
+                            'TESPy version 0.4.0. Please use "comp" instead.')
                         warnings.warn(msg, FutureWarning, stacklevel=2)
                     else:
                         comp = c['comp']
@@ -924,7 +924,7 @@ class bus:
                         if k == 'p':
                             msg = (
                                 'The dictionary keyword "p" will be removed '
-                                'TESPy version 0.3.2. Please use "param" '
+                                'TESPy version 0.4.0. Please use "param" '
                                 'instead.')
                             warnings.warn(msg, FutureWarning, stacklevel=2)
                         if isinstance(v, str) or v is None:
